@@ -54,7 +54,9 @@ def main(
             elif stitcher == "axio":
                 from axio2zarr import axio2zarr as raw2zarr
 
-            raw2zarr(input_path, output_path / "raw", local_cluster=False, append_name=False)
+            raw2zarr(
+                input_path, output_path / "raw", local_cluster=False, append_name=False
+            )
 
         input_path = output_path / "raw"
 
@@ -76,13 +78,13 @@ def main(
 
             create_tileset(output_path, "tileset")
 
-        if "bead_detect2" in recipes:
+        if "bead_detect" in recipes:
             logger.info("Running bead_detection recipe")
             from ..bead_detect.runner import bead_detect
 
-            bead_detect(output_path, overwrite=overwrite, fig=True)
+            bead_detect(output_path, overwrite=overwrite, fig=False)
 
-        if "bead_detect" in recipes:
+        if "bead_detect_alt" in recipes:
             logger.info("Running bead_detection recipe")
             from ..beadlib import beads
 
