@@ -19,9 +19,12 @@ __config = {
     "channel_to_use": 3,
     "norm_val": 1,
     "beads": {
-        "min_radius": 10,
+        "min_radius": 15,
         "max_radius": 150,
         "min_separation": 60,
+        "min_area": 3_000,
+        "max_area": 50_000,
+        "threshold": 6,
     },
 }
 
