@@ -40,9 +40,12 @@ __config = {
     "normal_y": 1000,
     "sections": None,
     "beads": {
-        "min_radius": 60,
+        "min_radius": 30,
         "max_radius": 150,
         "min_separation": 60,
+        "min_area": 3_000,
+        "max_area": 50_000,
+        "threshold": 6,
     },
 }
 
