@@ -95,7 +95,7 @@ class GenericSection:
     def normval(self, flats):
         pmax = max(p[1] for p in json.loads(flats.attrs["pval"]).values())
         scl = [1, 100, 1000, 10000, 100000]
-        j = np.searchsorted(scl, pmax / (2**16 - 1), side="right")
+        j = np.searchsorted(scl, pmax / (2 ** 16 - 1), side="right")
         val = scl[j]
         logger.debug(f"Using norm_val={val}")
         return val
@@ -119,7 +119,7 @@ class GenericSection:
         # Compute from flats
         Settings.norm_val = self.normval(cals["flats"])
         y, yh, x, xw = self.trimsec(cals["flats"])
-        Settings.y_min, Settings.y_max = y, yh
+        Settings.y_min, Settings.y_max = y + 20, yh - 20
         Settings.x_min, Settings.x_max = x, xw
 
         # Get channel to use with highest signal
@@ -378,7 +378,7 @@ class GenericSection:
             p1, p2 = pint.get_limits(arr.data.ravel())
             norm = (arr - p1) / (p2 - p1)
             norm = np.arcsinh(q * (norm - norm.min())) / q
-            norm = norm.clip(0, 1) * (2**8 - 1)
+            norm = norm.clip(0, 1) * (2 ** 8 - 1)
             return norm.astype("uint8")
 
         colours = ["red", "green", "blue", "cyan", "yellow", "magenta", "grey"]
