@@ -1,16 +1,18 @@
 import ctypes
 import importlib
 import os
+from functools import wraps
+import sys
 import cv2
 import dask.array as da
 import numpy as np
-
 from dask import delayed
 from dask.distributed import get_client, wait
 from shapely.geometry import Polygon
 from skimage.transform import warp
-from functools import wraps
+
 import imaxt_mosaic.plugins
+
 from .settings import Settings
 
 # Generic functions
@@ -45,6 +47,22 @@ def umask(func):
     return wrapper
 
 
+def cleanup(output_path):
+    for root, dirs, files in os.walk(output_path):
+        os.chmod(root, 0o555)
+        for file in files:
+            os.chmod(os.path.join(root, file), 0o444)
+
+
+def initialize(output_path):
+    if not output_path.exists():
+        return
+    for root, dirs, files in os.walk(output_path):
+        os.chmod(root, 0o755)
+        for file in files:
+            os.chmod(os.path.join(root, file), 0o644)
+
+
 # Image processing
 
 
@@ -195,7 +213,7 @@ def fuse(
                 raise
     a = a / (cf + 1e-10)
     a = (a + bzero) * bscale
-    a = a.clip(0, 2 ** 16 - 1)
+    a = a.clip(0, 2**16 - 1)
     return a.astype(dtype)
 
 
@@ -301,13 +319,21 @@ def trim_memory_workers(worker=None):
 
 
 def trim_memory() -> int:
-    libc = ctypes.CDLL("libc.so.6")
-    return libc.malloc_trim(0)
+    if 'darwin' in str(sys.platform).lower():
+        libc = ctypes.CDLL("libc.dylib")
+        libc.free(0)
+    else:
+        libc = ctypes.CDLL("libc.so.6")
+        return libc.malloc_trim(0)
 
 
 def get_memory_usage():
-    libc = ctypes.CDLL("libc.so.6")
-    return libc.malloc_usable_size(0)
+    if 'darwin' in str(sys.platform).lower():
+        libc = ctypes.CDLL("libc.dylib")
+        return libc.malloc_good_size(0)
+    else:
+        libc = ctypes.CDLL("libc.so.6")
+        return libc.malloc_usable_size(0)
 
 
 def get_workers_info():
